#
# spec file for package python-usbsdmux
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         orig_name usbsdmux
Name:           python-usbsdmux
Version:        24.11.1
Release:        1.2
Summary:        Tool to control an usb-sd-mux from the command line
License:        LGPL-2.1-or-later
URL:            https://github.com/linux-automation/usbsdmux
Source0:        https://files.pythonhosted.org/packages/source/u/usbsdmux/usbsdmux-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(udev)
Requires:       %{orig_name}-udev
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
Tool to control USB-SD-mux hardware from linux-automation.com

Full manual is available at https://www.linux-automation.com/usbsdmux-M01/

%package -n %{orig_name}-udev
Summary:        Udev rules for usbsdmux

%description -n %{orig_name}-udev
Udev rules for usbsdmux

%prep
%autosetup -p1 -n %{orig_name}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
# Fix interpreter
%{python_expand # Fix all supported python version
for i in %{buildroot}%{$python_sitelib}/usbsdmux/*.py; do
    sed -i 's#%{_bindir}/env python3#%{_bindir}/python3#' $i
    chmod +x $i
done
}
%python_clone -a %{buildroot}%{_bindir}/usbsdmux
%python_clone -a %{buildroot}%{_bindir}/usbsdmux-configure
# Install udev rules (and switch from 'plugdev' group to 'disk' group)
sed -i 's/plugdev/disk/' contrib/udev/99-usbsdmux.rules
mkdir -p %{buildroot}%{_udevrulesdir}
cp contrib/udev/99-usbsdmux.rules %{buildroot}%{_udevrulesdir}
# Run fdupes
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative usbsdmux
%python_install_alternative usbsdmux-configure

%postun
%python_uninstall_alternative usbsdmux
%python_uninstall_alternative usbsdmux-configure

%post -n %{orig_name}-udev
%udev_rules_update

%postun -n %{orig_name}-udev
%udev_rules_update

%files %{python_files}
%doc README.rst
%license COPYING
%python_alternative %{_bindir}/usbsdmux
%python_alternative %{_bindir}/usbsdmux-configure
%{python_sitelib}/usbsdmux
%{python_sitelib}/usbsdmux-%{version}.dist-info

%files -n %{orig_name}-udev
%{_udevrulesdir}/*.rules

%changelog
* Wed Nov 20 2024 Dirk Müller <dmueller@suse.com>
- update to 24.11.1:
  * Please note the breaking changes in 24.11.
- update to 24.11:
  * With this release we fix an issue with the numbering of the
    open drain outputs of the USB-SD-Mux FAST (see #83).
  * With this release the numbering of the open drain output
    changes.
  * Testing: Allow running tests locally and make README-test
    more verbose
  * README: fixes, tweaks and re-organisation
  * CI: streamline and add build and codespell targets
  * QA: Use ruff instead of black + flake8 for formatting and
    linting
  * pyproject.toml: switch over from setup.py
  * CI: add automatic publication to pypi.org and test.pypi.org
  * usbsdmux: remove the deprecated service/client code paths
  * usbsdmux: add ruff "UP" rules to config and fix issues
    automatically
  * pyproject.toml: fix fallout from the migration
  * usb-sd-mux/FAST: Fix GPIO number-to-pin definition
* Thu Jun 13 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Switch from 'plugdev' group to 'disk' group for udev rule
- Update to 24.01.1:
  * introduce (optional) logging of meta-data via MQTT.
    See the README for more details on how to use it.
  * What's Changed
  - Add statistics via mqtt by @BedaKraus in #68
  - README: Update DCO to follow the kernel wording by @SmithChart in #70
- Skipped 24.01:
  * Our tool can now read the SCR, CID and CSD SD card registers from
    the card reader ID, decode their contents and print the result on
    the screen. Give the usbsdmux /dev/sg0 info command a try.
  * Since the register contents are structured information we decided
    to add a JSON-output, so the information can be used by other tools.
  * What's Changed
  - implement 'info' command to show SD card SCR, CID and CSD by @jluebbe in #58
  - Add JSON status output for all commands and errors by @SmithChart in #60
  - Add support for decoding SCR, CID and CSD registers by @jluebbe in #62
  - Add pytest tests and a GitHub Actions workflow for SD register decoding by @jluebbe in #63
  - add test that checks README.rst against usbsdmux -h output by @jluebbe in #65
- Skipped 0.3.0:
  * add support for a new hardware revision of our USB-SD-Mux.
  * The new hardware features two open-drain outputs and is built
    around a new I2C port expander and a faster analog switch for
    the SD-Card.
  * Breaking Changes:
  - If you are using this tool as a Python library: This release
    changes the API. The usbsdmux.UsbSdMux class is now an abstract
    base class and can not be instantiated directly. Use the
    usbsdmux.autoselect_driver() function to obtain an instance of
    the correct type.
  * What's Changed:
  - Cleanups for usb2642i2c by @ukleinek in #42
  - create a basic debian package by @jluebbe in #38
  - flake8 and black: Fix Problems and add Actions for verification by @SmithChart in #47
  - README: fix typo in UDEV rule path by @remes-codasip in #54
  - Drop debian packaging by @ukleinek in #53
  - Add support for the USB-SD-Mux FAST by @SmithChart in #52
  - Increment package version to 0.3.0 by @SmithChart in #56
* Thu Mar 17 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 0.2.1. Main changes:
  * cli: Handle well-known Exceptions
  * usb2642i2c: Do not create if device node does not exist
  * commandline: 'get' must respect hardware signal priority
- Main changes in 0.2.0:
  * Remove the service/client split and access /dev/sg* directly
  * usb2642i2c: Fix sg device open arguments
  * Simplify the read-only to read-write mode transition
  * usbsdmux: honor wait argument in mode_disconnect()
  * main/service: add get action
  * usdbsdmux: set/enable default output values only for writes
* Wed May 20 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Move udev to a separate package
- Use update-alternatives
* Wed Apr 22 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add udev rule to have /dev/usb-sd-mux/id-<SERIAL> links
* Wed Apr 22 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Version 0.1.8
